# Plex Builders

This builder finds its items by using the features of Plex.

No configuration is required for these builders.

| Attribute                                     | Description                                                              | Works with Movies | Works with Shows | Works with Playlists and Custom Sort |
|:----------------------------------------------|:-------------------------------------------------------------------------|:-----------------:|:----------------:|:------------------------------------:|
| [`plex_all`](#plex-all)                       | Gets every movie/show in your library. Useful with [Filters](../filters) |      &#9989;      |     &#9989;      |               &#10060;               |
| [`plex_watchlist`](#plex-watchlist)           | Gets every movie/show in your Watchlist.                                 |      &#9989;      |     &#9989;      |               &#9989;                |
| [`plex_pilots`](#plex-pilots)                 | Gets the first episode of every show in your library                     |     &#10060;      |     &#9989;      |               &#9989;                |
| [`plex_collectionless`](#plex-collectionless) | Gets every movie/show that is not in a collection                        |      &#9989;      |     &#9989;      |               &#10060;               |
| [`plex_search`](#plex-search)                 | Gets every movie/show based on the search parameters provided            |      &#9989;      |     &#9989;      |               &#9989;                |

## Plex All

Finds every item in your library. Useful with [Filters](../filters).

The expected input is either true or false.

```yaml
collections:
  9.0 Movies:
    plex_all: true
    filters:
      rating.gte: 9
```

## Plex Watchlist

Finds every item in your Watchlist.

The expected input is the sort you want returned. It defaults to `added.asc`.

### Watchlist Sort Options

| Sort Option                                 | Description                                 |
|:--------------------------------------------|:--------------------------------------------|
| `title.asc`<br>`title.desc`                 | Sort by Title                               |
| `release.asc`<br>`release.desc`             | Sort by Release Date (Originally Available) |
| `critic_rating.asc`<br>`critic_rating.desc` | Sort by Critic Rating                       |
| `added.asc`<br>`added.desc`                 | Sort by Date Added to your Watchlist        |

The `sync_mode: sync` and `collection_order: custom` Details are recommended.

```yaml
collections:
  My Watchlist:
    plex_watchlist: critic_rating.desc
    collection_order: custom
    sync_mode: sync
```

## Plex Pilots

Gets the first episode of every show in your library. This only works with `builder_level: episode`

```yaml
collections:
  Pilots:
    builder_level: episode
    plex_pilots: true
```

## Plex Collectionless

**This is not needed if you're using [Smart Label Collections](smart.md#smart-label).**

Finds every item that is not in a collection unless the collection is in the exclusion list. This is a special collection type to help keep your library looking correct. When items in your library are in multiple collections it can mess up how they're displayed in your library.

For Example, if you have a `Marvel Cinematic Universe` Collection set to `Show this collection and its items` and an `Iron Man` Collection set to `Hide items in this collection` what happens is the show overrides the hide, and you end up with both the collections and the 3 Iron Man movies all displaying.

Alternatively, if you set the `Marvel Cinematic Universe` Collection to `Hide items in this collection` then movies without a collection like `The Incredible Hulk` will be hidden from the library view.

To combat the problem above you set all collections to `Hide items in this collection` then create a collection set to `Hide collection` and put every movie that you still want to display in that collection. 

With the variability of collections generated by the Plex Meta Manager maintaining a collection like this becomes very difficult, so in order to automate it, you can use `plex_collectionless`. You just have to tell it what collections to exclude or what collection prefixes to exclude.

There are two attributes for `plex_collectionless`:
* `exclude`: Exclude these Collections from being considered for collectionless. 
* `exclude_prefix` Exclude Collections whose title or sort title starts with a prefix from being considered for collectionless. 
 
**At least one exclusion is required.**

```yaml
collections:
  Collectionless:
    plex_collectionless:
      exclude_prefix:
        - "!"
        - "+"
        - "~"
      exclude: 
        - Marvel Cinematic Universe
    sort_title: ~_Collectionless
    collection_order: alpha
    collection_mode: hide
```

* Both `exclude` and `exclude_prefix` can take multiple values as a List.
* This is a known issue with Plex Collection and there is a [Feature Suggestion](https://forums.plex.tv/t/collection-display-issue/305406) detailing the issue more on their forms.

## Plex Search

Uses Plex's [Advanced Filters](https://support.plex.tv/articles/201273953-collections/) to find all items based on the search parameters provided.

Any Advanced Filter made using the Plex UI should be able to be recreated using `plex_search`. If you're having trouble getting `plex_search` to work correctly, build the collection you want inside of Plex's Advanced Filters and take a screenshot of the parameters in the Plex UI and post it in either the [Discussions](https://github.com/meisnate12/Plex-Meta-Manager/discussions) or on [Discord](https://discord.gg/TsdpsFYqqm), and I'll do my best to help you. 

like Plex's [Advanced Filters](https://support.plex.tv/articles/201273953-collections/) you have to start each search with either `any` or `all` as a base. You can only have one base attribute and all search attributes must be under the base.

Inside the base attribute you can use any search below or nest more `any` or `all`. You can have as many nested `any` or `all` next to each other as you want. If using multiple `any` or `all` you will have to do so in the form of a list.  

**Note: To search by `season`, `episode`, `album`, or `track` you must use the `builder_level` [Detail](../details/metadata) to change the type of items the collection holds.**

There are a couple other attributes you can have at the top level only along with the base attribute are:

## Special Attributes

| Attribute  | Description & Values                                                                                                                                                                                                                                     |
|:-----------|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `limit`    | **Description:** The max number of item for the search.<br>**Default:** `all`<br>**Values:** `all` or a number greater than 0                                                                                                                            |
| `sort_by`  | **Description:** This will control how the filter is sorted in your library. You can do a multi-level sort using a list.<br>**Default:** `random`<br>**Values:** Any sort options for your search type in the [Sorts Options Table](#sort-options)       |
| `type`     | **PLAYLIST SEARCHES ONLY** **Description:** Allows different types of media to be searched for.<br>**Default:** `movie`, `show`, or `artist` depending on library type<br>**Values:** `movie`, `show`, `season`, `episode`, `artist`, `album` or `track` |
| `validate` | **Description:** Determines if a collection/playlist will fail on a validation error<br>**Default:** `true`<br>**Values**: `true` or `false`                                                                                                             |

## Sort Options

| Sort Option                                     | Description                                         |  Movies  |  Shows   | Seasons  | Episodes | Artists  |  Albums  |  Tracks  |
|:------------------------------------------------|:----------------------------------------------------|:--------:|:--------:|:--------:|:--------:|:--------:|:--------:|:--------:|
| `title.asc`<br>`title.desc`                     | Sort by Title                                       | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#9989;  | &#9989;  | &#9989;  |
| `season.asc`<br>`season.desc`                   | Sort by Season                                      | &#10060; | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; | &#10060; |
| `show.asc`<br>`show.desc`                       | Sort by Show                                        | &#10060; | &#10060; | &#9989;  | &#9989;  | &#10060; | &#10060; | &#10060; |
| `album_artist.asc`<br>`album_artist.desc`       | Sort by Album Artist                                | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  | &#9989;  |
| `artist.asc`<br>`artist.desc`                   | Sort by Artist                                      | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  |
| `album.asc`<br>`album.desc`                     | Sort by Album                                       | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  |
| `year.asc`<br>`year.desc`                       | Sort by Year                                        | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#10060; | &#9989;  | &#10060; |
| `release.asc`<br>`release.desc`                 | Sort by Release Date (Originally Available)         | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#10060; | &#9989;  | &#10060; |
| `episode_release.asc`<br>`episode_release.desc` | Sort by Episode Release Date (Originally Available) | &#10060; | &#9989;  | &#9989;  | &#9989;  | &#10060; | &#10060; | &#10060; |
| `critic_rating.asc`<br>`critic_rating.desc`     | Sort by Critic Rating                               | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#10060; | &#9989;  | &#10060; |
| `audience_rating.asc`<br>`audience_rating.desc` | Sort by Audience Rating                             | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; |
| `user_rating.asc`<br>`user_rating.desc`         | Sort by User Rating                                 | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  |
| `content_rating.asc`<br>`content_rating.desc`   | Sort by Content Rating                              | &#9989;  | &#9989;  | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; |
| `duration.asc`<br>`duration.desc`               | Sort by Duration                                    | &#9989;  | &#10060; | &#10060; | &#9989;  | &#10060; | &#10060; | &#9989;  |
| `progress.asc`<br>`progress.desc`               | Sort by Progress                                    | &#10060; | &#10060; | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; |
| `played.asc`<br>`played.desc`                   | Sort by Date Last Played                            | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  | &#9989;  | &#9989;  |
| `plays.asc`<br>`plays.desc`                     | Sort by Number of Plays                             | &#9989;  | &#10060; | &#10060; | &#9989;  | &#9989;  | &#9989;  | &#9989;  |
| `unplayed.asc`<br>`unplayed.desc`               | Sort by Unplayed                                    | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; |
| `episode_added.asc`<br>`episode_added.desc`     | Sort by Last Episode Date Added                     | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; |
| `added.asc`<br>`added.desc`                     | Sort by Date Added                                  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  |
| `viewed.asc`<br>`viewed.desc`                   | Sort by Date Last Viewed                            | &#9989;  | &#9989;  | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; |
| `rated.asc`<br>`rated.desc`                     | Sort by Date Last Rated                             | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  |
| `popularity.asc`<br>`popularity.desc`           | Sort by Popularity                                  | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#10060; | &#9989;  |
| `resolution.asc`<br>`resolution.desc`           | Sort by Resolution                                  | &#9989;  | &#10060; | &#10060; | &#9989;  | &#10060; | &#10060; | &#10060; |
| `bitrate.asc`<br>`bitrate.desc`                 | Sort by Bitrate                                     | &#9989;  | &#10060; | &#10060; | &#9989;  | &#10060; | &#10060; | &#9989;  |
| `random`                                        | Sort by Random                                      | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  | &#9989;  |

## Searches

There are three fields per search option when using Plex's Advanced Filters in the Web UI. 

1. **Attribute:** What attribute you wish to search.
2. **Modifier:** Which modifier to use.
3. **Value:** Actual value to search.

**Example:** `Attribute.Modifier: Value`

## String Searches

String searches can be used with either no modifier or with `.not`, `.is`, `.isnot`, `.begins`, or `.ends`.

String search can take multiple values **only as a list**.

### String Modifiers

| String Modifier | Description                                                                    | Plex Web UI Display |
|:----------------|:-------------------------------------------------------------------------------|:-------------------:|
| No Modifier     | Matches every item where the attribute contains the given string               |     `contains`      |
| `.not`          | Matches every item where the attribute does not contain the given string       | `does not contain`  |
| `.is`           | Matches every item where the attribute exactly matches the given string        |        `is`         |
| `.isnot`        | Matches every item where the attribute does not exactly match the given string |      `is not`       |
| `.begins`       | Matches every item where the attribute begins with the given string            |    `begins with`    |
| `.ends`         | Matches every item where the attribute ends with the given string              |     `ends with`     |

### String Attributes

| String Search        | Description                                              | Movie<br>Libraries | Show<br>Libraries | Music<br>Libraries |
|:---------------------|:---------------------------------------------------------|:------------------:|:-----------------:|:------------------:|
| `title`              | Uses the title attribute to match                        |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_title`      | Uses the title attribute of the show's episodes to match |      &#10060;      |      &#9989;      |      &#10060;      |
| `studio`             | Uses the studio attribute to match                       |      &#9989;       |      &#9989;      |      &#10060;      |
| `edition`            | Uses the edition attribute to match                      |      &#9989;       |     &#10060;      |      &#10060;      |
| `artist_title`       | Uses the Artist's Title attribute to match               |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_title`        | Uses the Album's Title attribute to match                |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_title`        | Uses the Track's Title attribute to match                |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_record_label` | Uses the Album's Record Label attribute to match         |      &#10060;      |     &#10060;      |      &#9989;       |

## Tag Searches

Tag searches can be used with either no modifier or with `.not` except for `decade` and `resolution` which can only be used with no modifier.

Tag search can take multiple values as a **list or a comma-separated string**.

### Tag Modifiers

| Tag Modifier | Description                                                             | Plex Web UI Display |
|:-------------|:------------------------------------------------------------------------|:-------------------:|
| No Modifier  | Matches every item where the attribute matches the given string         |        `is`         |
| `.not`       | Matches every item where the attribute does not match the given string  |      `is not`       |
| `.regex`     | Matches every item where one value of this attribute matches the regex. |        `N/A`        |

### Tag Attributes

| Tag Search                 | Description                                                                 | Movie<br>Libraries | Show<br>Libraries | Music<br>Libraries |
|:---------------------------|:----------------------------------------------------------------------------|:------------------:|:-----------------:|:------------------:|
| `actor`                    | Uses the actor tags to match                                                |      &#9989;       |      &#9989;      |      &#10060;      |
| `audio_language`           | Uses the audio language tags to match                                       |      &#9989;       |      &#9989;      |      &#10060;      |
| `collection`               | Uses the collection tags to match for top level collections                 |      &#9989;       |      &#9989;      |      &#10060;      |
| `season_collection`        | Uses the collection tags to match for season collections                    |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_collection`       | Uses the collection tags to match for episode collections                   |      &#10060;      |      &#9989;      |      &#10060;      |
| `content_rating`           | Uses the content rating tags to match                                       |      &#9989;       |      &#9989;      |      &#10060;      |
| `country`                  | Uses the country tags to match                                              |      &#9989;       |     &#10060;      |      &#10060;      |
| `decade`<sup>1</sup>       | Uses the year tag to match the decade                                       |      &#9989;       |     &#10060;      |      &#10060;      |
| `director`                 | Uses the director tags to match                                             |      &#9989;       |     &#10060;      |      &#10060;      |
| `genre`                    | Uses the genre tags to match                                                |      &#9989;       |      &#9989;      |      &#10060;      |
| `label`                    | Uses the label tags to match for top level collections                      |      &#9989;       |      &#9989;      |      &#10060;      |
| `season_label`             | Uses the label tags to match for season collections                         |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_label`            | Uses the label tags to match for episode collections                        |      &#10060;      |      &#9989;      |      &#10060;      |
| `network`                  | Uses the network tags to match<br>**Only works with the New Plex TV Agent** |      &#10060;      |      &#9989;      |      &#10060;      |
| `producer`                 | Uses the actor tags to match                                                |      &#9989;       |     &#10060;      |      &#10060;      |
| `resolution`               | Uses the resolution tags to match                                           |      &#9989;       |      &#9989;      |      &#10060;      |
| `subtitle_language`        | Uses the subtitle language tags to match                                    |      &#9989;       |      &#9989;      |      &#10060;      |
| `writer`                   | Uses the writer tags to match                                               |      &#9989;       |     &#10060;      |      &#10060;      |
| `year`<sup>1</sup>         | Uses the year tag to match                                                  |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_year`<sup>1</sup> | Uses the year tag to match                                                  |      &#10060;      |      &#9989;      |      &#10060;      |
| `artist_genre`             | Uses the Artist's Genre attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_collection`        | Uses the Artist's Collection attribute to match                             |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_country`           | Uses the Artist's Country attribute to match                                |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_mood`              | Uses the Artist's Mood attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_style`             | Uses the Artist's Style attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_label`             | Uses the Artist's Label attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_genre`              | Uses the Album's Genre attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_mood`               | Uses the Album's Mood attribute to match                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_style`              | Uses the Album's Style attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_format`             | Uses the Album's Format attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_type`               | Uses the Album's Type attribute to match                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_collection`         | Uses the Album's Collection attribute to match                              |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_source`             | Uses the Album's Source attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_label`              | Uses the Album's Label attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_mood`               | Uses the Track's Mood attribute to match                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_source`             | Uses the Track's Source attribute to match                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_label`              | Uses the Track's Label attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |

<sup>1</sup> You can use `current_year` to have PMM use the current years value. This can be combined with a `-#` at the end to subtract that number of years. i.e. `current-2`

## Date Searches

Date searches can be used with either no modifier or with `.not`, `.before`, or `.after`.

No date search can take multiple values.

### Date Modifiers

| Date Modifier | Description                                                                                                                                                | Plex Web UI Display  |
|:--------------|:-----------------------------------------------------------------------------------------------------------------------------------------------------------|:--------------------:|
| No Modifier   | Matches every item where the date attribute is in the last X days<br>**Format:** number of days<br>**Example:** `30`                                       |   `is in the last`   |
| `.not`        | Matches every item where the date attribute is not in the last X days<br>**Format:** number of days<br>**Example:** `30`                                   | `is not in the last` |
| `.before`     | Matches every item where the date attribute is before the given date<br>**Format:** MM/DD/YYYY or `today` for the current day<br>**Example:** `01/01/2000` |     `is before`      |
| `.after`      | Matches every item where the date attribute is after the given date<br>**Format:** MM/DD/YYYY or `today` for the current day<br>**Example:** `01/01/2000`  |      `is after`      |

### Date Attributes

| Date Search           | Description                                                                        | Movie<br>Libraries | Show<br>Libraries | Music<br>Libraries |
|:----------------------|:-----------------------------------------------------------------------------------|:------------------:|:-----------------:|:------------------:|
| `added`               | Uses the date added attribute to match                                             |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_added`       | Uses the date added attribute of the show's episodes to match                      |      &#10060;      |      &#9989;      |      &#10060;      |
| `release`             | Uses the release date attribute (originally available) to match                    |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_air_date`    | Uses the air date attribute (originally available) of the show's episodes to match |      &#10060;      |      &#9989;      |      &#10060;      |
| `last_played`         | Uses the date last played attribute to match                                       |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_last_played` | Uses the date last played attribute of the show's episodes to match                |      &#10060;      |      &#9989;      |      &#10060;      |
| `artist_added`        | Uses the Artist's date added attribute to match                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_last_played`  | Uses the Artist's last played attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_last_played`   | Uses the Album's last played attribute to match                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_added`         | Uses the Album's date added attribute to match                                     |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_released`      | Uses the Album's release date attribute to match                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_last_played`   | Uses the Track's date last played attribute to match                               |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_last_skipped`  | Uses the Track's date last skipped attribute to match                              |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_last_rated`    | Uses the Track's date last rated attribute to match                                |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_added`         | Uses the Track's date added attribute to match                                     |      &#10060;      |     &#10060;      |      &#9989;       |

## Number Searches

Number searches must use `.gt`, `.gte`, `.lt`, or `.lte` as a modifier only the rating searches can use `.rated`.

No number search can take multiple values.

### Number Modifiers

| Number Modifier | Description                                                                                                                                             | Plex Web UI Display |
|:----------------|:--------------------------------------------------------------------------------------------------------------------------------------------------------|:-------------------:|
| `.gt`           | Matches every item where the number attribute is greater than the given number<br>**Format:** number<br>**Example:** `30`, `1995`, or `7.5`             |  `is greater than`  |
| `.gte`          | Matches every item where the number attribute is greater than or equal to the given number<br>**Format:** number<br>**Example:** `30`, `1995`, or `7.5` |         N/A         |
| `.lt`           | Matches every item where the number attribute is less than the given number<br>**Format:** number<br>**Example:** `30`, `1995`, or `7.5`                |   `is less than`    |
| `.lte`          | Matches every item where the number attribute is less than or equal to the given number<br>**Format:** number<br>**Example:** `30`, `1995`, or `7.5`    |         N/A         |
| `.rated`        | Matches every item either rated or not rated<br>**Format:** `true` or `false`                                                                           |         N/A         |

* `.rated` only works for rating searches

### Number Attributes

| Number Search              | Description                                                                                     | Movie<br>Libraries | Show<br>Libraries | Music<br>Libraries |
|:---------------------------|:------------------------------------------------------------------------------------------------|:------------------:|:-----------------:|:------------------:|
| `duration`                 | Uses the duration attribute to match using minutes<br>**Minimum:** `0`                          |      &#9989;       |     &#10060;      |      &#10060;      |
| `plays`                    | Uses the plays attribute to match<br>**Minimum:** `0`                                           |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_plays`            | Uses the Episode's plays attribute to match<br>**Minimum:** `0`                                 |      &#10060;      |      &#9989;      |      &#10060;      |
| `critic_rating`            | Uses the critic rating attribute to match<br>**Range:** `0.0` - `10.0`                          |      &#9989;       |      &#9989;      |      &#10060;      |
| `audience_rating`          | Uses the audience rating attribute to match<br>**Range:** `0.0` - `10.0`                        |      &#9989;       |      &#9989;      |      &#10060;      |
| `user_rating`              | Uses the user rating attribute to match<br>**Range:** `0.0` - `10.0`                            |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_user_rating`      | Uses the user rating attribute of the show's episodes to match<br>**Range:** `0.0` - `10.0`     |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_critic_rating`    | Uses the critic rating attribute of the show's episodes to match<br>**Range:** `0.0` - `10.0`   |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_audience_rating`  | Uses the audience rating attribute of the show's episodes to match<br>**Range:** `0.0` - `10.0` |      &#10060;      |      &#9989;      |      &#10060;      |
| `year`<sup>1</sup>         | Uses the year attribute to match<br>**Minimum:** `0`                                            |      &#9989;       |      &#9989;      |      &#10060;      |
| `episode_year`<sup>1</sup> | Uses the Episode's year attribute to match<br>**Minimum:** `0`                                  |      &#10060;      |      &#9989;      |      &#10060;      |
| `album_year`<sup>1</sup>   | Uses the Album's year attribute to match<br>**Minimum:** `0`                                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_decade`<sup>1</sup> | Uses the Album's decade attribute to match<br>**Minimum:** `0`                                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_plays`              | Uses the Album's plays attribute to match<br>**Minimum:** `0`                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_plays`              | Uses the Track's plays attribute to match<br>**Minimum:** `0`                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_skips`              | Uses the Track's skips attribute to match<br>**Minimum:** `0`                                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `artist_user_rating`       | Uses the Artist's user rating attribute to match<br>**Range:** `0.0` - `10.0`                   |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_user_rating`        | Uses the Album's user rating attribute to match<br>**Range:** `0.0` - `10.0`                    |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_critic_rating`      | Uses the Album's critic rating attribute to match<br>**Range:** `0.0` - `10.0`                  |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_user_rating`        | Uses the Track's user rating attribute to match<br>**Range:** `0.0` - `10.0`                    |      &#10060;      |     &#10060;      |      &#9989;       |

<sup>1</sup> You can use `current_year` to have PMM use the current years value. This can be combined with a `-#` at the end to subtract that number of years. i.e. `current-2`

## Boolean Searches

Boolean Searches take no modifier and can only be either `true` or `false`.

### Boolean Attributes

| Boolean Search      | Description            | Movie<br>Libraries | Show<br>Libraries | Music<br>Libraries |
|:--------------------|:-----------------------|:------------------:|:-----------------:|:------------------:|
| `hdr`               | Is HDR                 |      &#9989;       |      &#9989;      |      &#10060;      |
| `unmatched`         | Is Unmatched           |      &#9989;       |     &#10060;      |      &#10060;      |
| `duplicate`         | Is Duplicate           |      &#9989;       |     &#10060;      |      &#10060;      |
| `unplayed`          | Is Unplayed            |      &#9989;       |     &#10060;      |      &#10060;      |
| `progress`          | Is In Progress         |      &#9989;       |     &#10060;      |      &#10060;      |
| `trash`             | Is Trashed             |      &#9989;       |      &#9989;      |      &#10060;      |
| `unplayed_episodes` | Has Unplayed Episodes  |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_unplayed`  | Has Episodes Unplayed  |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_duplicate` | Has Duplicate Episodes |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_progress`  | Has Episode Progress   |      &#10060;      |      &#9989;      |      &#10060;      |
| `episode_unmatched` | Has Episodes Unmatched |      &#10060;      |      &#9989;      |      &#10060;      |
| `show_unmatched`    | Has Shows Unmatched    |      &#10060;      |      &#9989;      |      &#10060;      |
| `artist_unmatched`  | Is Artist's Unmatched  |      &#10060;      |     &#10060;      |      &#9989;       |
| `album_unmatched`   | Is Album's Unmatched   |      &#10060;      |     &#10060;      |      &#9989;       |
| `track_trash`       | Is Track Trashed       |      &#10060;      |     &#10060;      |      &#9989;       |

## Plex Search Examples

A few examples are listed below:

```yaml
collections:
  Documentaries:
    plex_search:
      all:
        genre: Documentary
```
```yaml
collections:
  Dave Chappelle Comedy:
    plex_search:
      all:
        actor: Dave Chappelle
        genre: Comedy
```
```yaml
collections:
  Top Action Movies:
    collection_order: custom
    plex_search:
      all:
        genre: Action
      sort_by: audience_rating.desc
      limit: 20
```
```yaml
collections:
  90s Movies:
    plex_search:
      any:
        year:
          - 1990
          - 1991
          - 1992
          - 1993
          - 1994
          - 1995
          - 1996
          - 1997
          - 1998
          - 1999
```
```yaml
collections:
  90s Movies:
    plex_search:
      any:
        decade: 1990
```
```yaml
collections:
  Best 2010+ Movies:
    collection_order: custom
    plex_search:
      all:
        year.gte: 2010
      sort_by: audience_rating.desc
      limit: 20
```

Here's an example of an episode collection using `plex_search`.

```yaml
 collections:
   Top 100 Simpsons Episodes:
     collection_order: custom
     builder_level: episode
     plex_search:
       type: episodes
       sort_by: audience_rating.desc
       limit: 100
       all:
         title.ends: "Simpsons"
     summary: A collection of the highest rated simpsons epsodes.
```

If you specify TMDb Person ID's using the Detail `tmdb_person` and then tell either `actor`, `director`, `producer`, or `writer` to add `tmdb`, the script will translate the TMDb Person IDs into their names and run the search on those names.

```yaml
collections:
  Robin Williams:
    plex_search:
      all:
        actor: tmdb
    tmdb_person: 2157
```
```yaml
collections:
  Steven Spielberg:
    plex_search:
      all:
        director: tmdb
    tmdb_person: https://www.themoviedb.org/person/488-steven-spielberg
```
```yaml
collections:
  Quentin Tarantino:
    plex_search:
      any:
        actor: tmdb
        director: tmdb
        producer: tmdb
        writer: tmdb
    tmdb_person: 138
```
