# Definition Settings

All the following attributes serve various functions as how the definition functions inside of Plex Meta Manager.

| Attribute                    | Description & Values                                                                                                                                                                                                                                                                                                                                                                               |
|:-----------------------------|:---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `name`                       | **Description:** Used to specify the name of the definition in Plex as different than the mapping name.<br>**Values:** Any String                                                                                                                                                                                                                                                                  |
| `limit`                      | **Description:** Used to specify the max number of items for the definition<br>**Values:** Number greater than 0                                                                                                                                                                                                                                                                                   | 
| `template`                   | **Description:** Used to specify a template and template variables to use for this definition. See the [Templates Page](../templates) for more information.<br>**Values:** Dictionary                                                                                                                                                                                                              |
| `run_again`                  | **Description:** Used to try and add all the missing items to the definition again after the daily run.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                   |
| `sync_mode`                  | **Description:** Used to change how builders sync with this definition.<br>**Default:** `sync_mode` [settings value](../../config/settings) in the Configuration File<br>**Values:**<table class="clearTable"><tr><td>`append`</td><td>Only Add Items to the Collection</td></tr><tr><td>`sync`</td><td>Add & Remove Items from the Collection</td></tr></table>                                   |
| `minimum_items`              | **Description:** Minimum items that must be found to add to a definition.<br>**Default:** `minimum_items` [settings value](../../config/settings) in the Configuration File<br>**Values:** number greater than 0                                                                                                                                                                                   |
| `delete_below_minimum`       | **Description:** Deletes the definition if below the minimum.<br>**Default:** `delete_below_minimum` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                            |
| `delete_not_scheduled`       | **Description:** Deletes the definition if its skipped because its not scheduled.<br>**Default:** `delete_not_scheduled` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                        |
| `tmdb_region`                | **Description:** Sets the region for `tmdb_popular`, `tmdb_now_playing`, `tmdb_top_rated`, and `tmdb_upcoming`                                                                                                                                                                                                                                                                                     |
| `validate_builders`          | **Description:** When set to false the definition will not fail if one builder fails.<br>**Default:** `true`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                                      |
| `cache_builders`             | **Description:** Caches the items found by the builders for a number of days. This is useful if you run the same configuration on multiple libraries/servers in one run just set the value to `1`.<br>**Default:** `0` <br>**Values:** number 0 or greater                                                                                                                                         | 
| `blank_collection`           | **Description:** When set to true the collection will be created with no builders and no items added.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                     |
| `build_collection`           | **Description:** When set to false the collection won't be created but items can still be added to Radarr/Sonarr. Does not work for playlists.<br>**Default:** `true`<br>**Values:** `true` or `false`                                                                                                                                                                                             |
| `server_preroll`             | **Description:** Used to set the `Movie pre-roll video` Text box in Plex under Settings -> Extras.<br>You can run this with a [schedule](schedule) to change the pre-rolls automatically.<br>**Values:** Any String                                                                                                                                                                                |
| `missing_only_released`      | **Description:** definition Level `missing_only_released` toggle.<br>**Default:** `missing_only_released` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                       |
| `only_filter_missing`        | **Description:** definition Level `only_filter_missing` toggle.<br>**Default:** `only_filter_missing` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                           |
| `show_filtered`              | **Description:** definition level `show_filtered` toggle.<br>**Default:** `show_filtered` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                                       |
| `show_missing`               | **Description:** definition level `show_missing` toggle.<br>**Default:** `show_missing` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                                         |
| `save_report`                | **Description:** definition level `save_report` toggle.<br>**Default:** `save_report` [settings value](../../config/settings) in the Configuration File<br>**Values:** `true` or `false`                                                                                                                                                                                                           |
| `ignore_ids`                 | **Description:** definition level `ignore_ids` which is combined with the library and global `ignore_ids`.<br>**Default:** `ignore_ids` [settings value](../../config/settings) in the Configuration File<br>**Values:** List or comma-separated String of TMDb/TVDb IDs                                                                                                                           |
| `ignore_imdb_ids`            | **Description:** definition level `ignore_imdb_ids` which is combined with the library and global `ignore_imdb_ids`.<br>**Default:** `ignore_imdb_ids` [settings value](../../config/settings) in the Configuration File<br>**Values:** List or comma-separated String of IMDb IDs                                                                                                                 |
| `name_mapping`               | **Description:** Used to specify the folder name in the [Image Assets Directory](../../home/guides/assets) i.e. if your definition name contains characters that are not allowed in file paths (i.e. for windows `<`, `>`, `:`, `"`, `/`, `\`, `?`, `*` cannot be in the file path), but you want them in your name you can this to specify the name in the file system.<br>**Values:** Any String |
| `test`                       | **Description:** When running in Test Mode (`--run-tests` [option](../../home/environmental)) only definitions with `test: true` will be run.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                             |
| `changes_webhooks`           | **Description:** Used to specify a definition changes webhook for just this definition.<br>**Values:** List of webhooks                                                                                                                                                                                                                                                                            |
| `sync_to_trakt_list`         | **Description:** Used to specify a trakt list you want the definition synced to.<br>**Values:** Trakt List Slug you want to sync to                                                                                                                                                                                                                                                                |
| `sync_missing_to_trakt_list` | **Description:** Used to also sync missing items to the Trakt List specified by `sync_to_trakt_list`.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                     |
| `allowed_library_types`      | **Description:** Used to specify the types of libraries that this definition can work with.<br>Multiple can be used for one definition as a list or comma separated string. One `false` will cause it to fail.<br>**Values:** `movie`, `show`, `artist`, `true`, `false`                                                                                                                           |
| `default_percent`            | **Description:** Used to declare the default percent for `episodes`, `seasons`, `tracks`, and `albums` [special filters](../filters.md#special-filters). Default is 50.<br>**Values:** Integer between 1 and 100                                                                                                                                                                                   |
| `ignore_blank_results`       | **Description:** Used to not have Errors resulting from blank results from builders.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                                      |
| `only_run_on_create`         | **Description:** Used to only run the collection definition if the collection doesn't already exist.<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                      |
| `delete_collections_named`   | **Description:** Used to delete any collections in your plex named one of the given collections.<br>**Values:** List of Collection Names to delete                                                                                                                                                                                                                                                 |