# Item Metadata Updates

All the following attributes update various details of the metadata for every item in the collection. 

**None of these updates work with Playlists or Overlays.**

| Attribute                             | Description & Values                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
|:--------------------------------------|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `item_label`                          | **Description:** Appends new labels to every movie/show in the collection<br>**Values:** Comma-separated string of labels to append                                                                                                                                                                                                                                                                                                                                                                                                                 |
| `item_label.remove`                   | **Description:** Removes existing labels from every movie/show in the collection<br>**Values:** Comma-separated string of labels to remove                                                                                                                                                                                                                                                                                                                                                                                                          |
| `item_label.sync`                     | **Description:** Matches the labels of every movie/show in the collection to the labels provided (Leave blank to remove all labels)<br>**Values:** Comma-separated string of labels to sync                                                                                                                                                                                                                                                                                                                                                         |
| `item_genre`                          | **Description:** Appends new genres to every movie/show in the collection<br>**Values:** Comma-separated string of genres to append                                                                                                                                                                                                                                                                                                                                                                                                                 |
| `item_genre.remove`                   | **Description:** Removes existing genres from every movie/show in the collection<br>**Values:** Comma-separated string of genres to remove                                                                                                                                                                                                                                                                                                                                                                                                          |
| `item_genre.sync`                     | **Description:** Matches the genres of every movie/show in the collection to the genres provided (Leave blank to remove all genres)<br>**Values:** Comma-separated string of genres to sync                                                                                                                                                                                                                                                                                                                                                         |
| `item_edition`                        | **Description:** Replaced the edition of every movie in the collection<br>**Values:** Edition Name                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| `non_item_remove_label`               | **Description:** Matches every movie/show that has the given label and is not in the collection and removes the label<br>**Values:** Comma-separated string of labels to remove                                                                                                                                                                                                                                                                                                                                                                     |
| `item_lock_poster`                    | **Description:** Locks/Unlocks the poster of every movie/show in the collection<br>**Default:** `None`<br>**Values:**<table class="clearTable"><tr><td>`true`</td><td>Lock</td></tr><tr><td>`false`</td><td>Unlock</td></tr></table>                                                                                                                                                                                                                                                                                                                |
| `item_lock_background`                | **Description:** Locks/Unlocks the background of every movie/show in the collection<br>**Default:** `None`<br>**Values:**<table class="clearTable"><tr><td>`true`</td><td>Lock</td></tr><tr><td>`false`</td><td>Unlock</td></tr></table>                                                                                                                                                                                                                                                                                                            |
| `item_lock_title`                     | **Description:** Locks/Unlocks the title of every movie/show in the collection<br>**Default:** `None`<br>**Values:**<table class="clearTable"><tr><td>`true`</td><td>Lock</td></tr><tr><td>`false`</td><td>Unlock</td></tr></table>                                                                                                                                                                                                                                                                                                                 |
| `item_assets`                         | **Description:** Checks your assets folders for assets of every movie/show in the collection<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                                                                                                                                                                               |
| `item_refresh`                        | **Description:** Refreshes the metadata of every movie/show in the collection<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                                                                                                                                                                                              |
| `item_refresh_delay`                  | **Description:** Amount of time to wait between each `item_refresh` of every movie/show in the collection<br>**Default:** `0`<br>**Values:** Number greater than `0`                                                                                                                                                                                                                                                                                                                                                                                |
| `item_tmdb_season_titles`             | **Description:** Changes the season titles of every show in the collection to match TMDb<br>**Default:** `false`<br>**Values:** `true` or `false`                                                                                                                                                                                                                                                                                                                                                                                                   |
| `item_episode_sorting`<sup>1</sup>    | **Description:** Changes the episode sorting of every show in the collection<br>**Values:**<table class="clearTable"><tr><td>`default`</td><td>Library default</td></tr><tr><td>`oldest`</td><td>Oldest first</td></tr><tr><td>`newest`</td><td>Newest first</td></tr></table>                                                                                                                                                                                                                                                                      |
| `item_keep_episodes`<sup>1</sup>      | **Description:** Changes the keep episodes of every show in the collection<br>**Values:**<table class="clearTable"><tr><td>`all`</td><td>All episodes</td></tr><tr><td>`5_latest`</td><td>5 latest episodes</td></tr><tr><td>`3_latest`</td><td>3 latest episodes</td></tr><tr><td>`latest`</td><td>Latest episodes</td></tr><tr><td>`past_3`</td><td>Episodes added in the past 3 days</td></tr><tr><td>`past_7`</td><td>Episodes added in the past 7 days</td></tr><tr><td>`past_30`</td><td>Episodes added in the past 30 days</td></tr></table> |
| `item_delete_episodes`<sup>1</sup>    | **Description:** Changes the delete episodes of every show in the collection<br>**Values:**<table class="clearTable"><tr><td>`never`</td><td>Never</td></tr><tr><td>`day`</td><td>After a day</td></tr><tr><td>`week`</td><td>After a week</td></tr><tr><td>`refresh`</td><td>On next refresh</td></tr></table>                                                                                                                                                                                                                                     |
| `item_season_display`<sup>1</sup>     | **Description:** Changes the season display of every show in the collection<br>**Values:**<table class="clearTable"><tr><td>`default`</td><td>Library default</td></tr><tr><td>`show`</td><td>Show</td></tr><tr><td>`hide`</td><td>Hide</td></tr></table>                                                                                                                                                                                                                                                                                           |
| `item_episode_ordering`<sup>1</sup>   | **Description:** Changes the episode ordering of every show in the collection<br>**Values:**<table class="clearTable"><tr><td>`default`</td><td>Library default</td></tr><tr><td>`tmdb_aired`</td><td>The Movie Database (Aired)</td></tr><tr><td>`tvdb_aired`</td><td>TheTVDb (Aired)</td></tr><tr><td>`tvdb_dvd`</td><td>TheTVDb (DVD)</td></tr><tr><td>`tvdb_absolute`</td><td>TheTVDb (Absolute)</td></tr></table>                                                                                                                              |
| `item_metadata_language`<sup>2</sup>  | **Description:** Changes the metadata language of every movie/show in the collection<br>**Values:** `default`, `ar-SA`, `ca-ES`, `cs-CZ`, `da-DK`, `de-DE`, `el-GR`, `en-AU`, `en-CA`, `en-GB`, `en-US`, `es-ES`, `es-MX`, `et-EE`, `fa-IR`, `fi-FI`, `fr-CA`, `fr-FR`, `he-IL`, `hi-IN`, `hu-HU`, `id-ID`, `it-IT`, `ja-JP`, `ko-KR`, `lt-LT`, `lv-LV`, `nb-NO`, `nl-NL`, `pl-PL`, `pt-BR`, `pt-PT`, `ro-RO`, `ru-RU`, `sk-SK`, `sv-SE`, `th-TH`, `tr-TR`, `uk-UA`, `vi-VN`, `zh-CN`, `zh-HK`, `zh-TW`                                             |
| `item_use_original_title`<sup>2</sup> | **Description:** Changes the use original title of every movie/show in the collection<br>**Values:**<table class="clearTable"><tr><td>`default`</td><td>Library default</td></tr><tr><td>`no`</td><td>No</td></tr><tr><td>`yes`</td><td>Yes</td></tr></table>                                                                                                                                                                                                                                                                                       |

<sup>1</sup> Only works with TV Show Libraries

<sup>2</sup> Must be using the **New Plex Movie Agent** or the **New Plex TV Agent** 
